@@ -7,14 +7,14 @@ int32_t SPVM__MyZlib__test_gzopen_gzread(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   void* sp_file = stack[0].oval;
   
-  const char* file = env->get_chars(env, sp_file);
+  const char* file = env->get_chars(env, stack, sp_file);
   
   z_stream z;
 
   gzFile gz_fh = gzopen(file, "rb");
   
   if (gz_fh == NULL){
-    return env->die(env, "Can't open file \"%s\"\n", file);
+    return env->die_v2(env, stack, "Can't open file \"%s\"\n", __func__, __FILE__, __LINE__, file);
   }
   
   char buffer[256] = {0};
